en_zh = {
    "Politics": "政治",
    "Heresy": "邪教",
    "Terrorism": "恐怖主义",
    "Crime": "犯罪",
    "Porn": "色情",
    "Gamble": "赌博",
    "Contraband": "违禁品",
    "SensitiveEvent": "敏感事件",
    "Abuse": "辱骂",
    "IllegalWebsite": "违规网站",
    "Adv": "广告",
    "Normal": "健康",
    "OtherViolations": "其他违规",
}

id2level = {
    0: 'Pass',
    1: 'Review',
    2: 'Reject'
}

id2label = {
    100: '色情',
    200: '广告',
    300: '暴恐',
    400: '违禁品',  # 原 违禁
    500: '政治',
    600: '辱骂',  # 原 谩骂
    700: '灌水',
    900: '其他'
}



"""Compare files
"""
import pandas as pd
import json
from whisper_evaluate.config import id2label, id2level
from whisper_evaluate.utils import _get_result_type


def compare_yidun_whisper_results(result_file: str, target_file: str):
    df = pd.read_csv(result_file)
    df.columns = ["example", "yidun_json", "whisper_json"]
    df["yidun_predict"], df["yidun_type"], df["yidun_hints"] = zip(*df["yidun_json"].apply(parse_yidun_json))
    (df["whisper_predict"],
     df["whisper_type"],
     df["whisper_predict_trie"],
     df["whisper_type_trie"],
     df["whisper_match_words"],
     df["whisper_new_words"],
     df["whisper_review_words"]) = zip(*df["whisper_json"].apply(parse_whisper_json))
    df = df.drop(columns=["yidun_json", "whisper_json"])
    df.to_csv(target_file, index=False)


def parse_yidun_json(yidun_json: str, standard_json=False):
    if not standard_json:
        yidun_json = yidun_json.replace("'", '"')
    x = yidun_json.replace("\\x0", "")
    data = json.loads(x)
    data = data["result"]
    _type = id2label[data['labels'][0]['label']] if data['labels'] else '健康'
    _hint = " ".join(data['labels'][0]['details']['hint'] if data['labels'] else [])
    predict_label = id2level[data['labels'][0]['level']] if data['labels'] else 'Pass'

    return predict_label, _type, _hint


def parse_whisper_json(whisper_json: str, standard_json=False):
    if not standard_json:
        whisper_json = whisper_json.replace("'", '"')
    a = json.loads(whisper_json)
    results = a['results'][0]
    _match_words = results['matched_words']
    _new_words = results['new_words']
    _review_words = results['review_words']
    predict_type = _get_result_type(_match_words + _new_words)
    predict_label = "Pass" if predict_type == "健康" else "Reject"
    predict_type_trie = "政治" if _get_result_type(_review_words) == "政治" else predict_type
    predict_label_trie = "Pass" if predict_type_trie == "健康" else "Reject"
    return (predict_label,
            predict_type,
            predict_label_trie,
            predict_type_trie,
            " ".join([x["word"] for x in _match_words]),
            " ".join([x["word"] for x in _new_words]),
            " ".join([x["word"] for x in _review_words]))
